==> kubernetes-model-core-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/FlockerVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FlockerVolumeSourceFluent<A extends FlockerVolumeSourceFluent<A>> extends BaseFluent<A>{
  public FlockerVolumeSourceFluent() {
  }
  
  public FlockerVolumeSourceFluent(FlockerVolumeSource instance) {
    this.copyInstance(instance);
  }
  private String datasetName;
  private String datasetUUID;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FlockerVolumeSource instance) {
    instance = (instance != null ? instance : new FlockerVolumeSource());
  
    if (instance != null) {
        this.withDatasetName(instance.getDatasetName());
        this.withDatasetUUID(instance.getDatasetUUID());
        this.withDatasetName(instance.getDatasetName());
        this.withDatasetUUID(instance.getDatasetUUID());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDatasetName() {
    return this.datasetName;
  }
  
  public A withDatasetName(String datasetName) {
    this.datasetName=datasetName; return (A) this;
  }
  
  public boolean hasDatasetName() {
    return this.datasetName != null;
  }
  
  public String getDatasetUUID() {
    return this.datasetUUID;
  }
  
  public A withDatasetUUID(String datasetUUID) {
    this.datasetUUID=datasetUUID; return (A) this;
  }
  
  public boolean hasDatasetUUID() {
    return this.datasetUUID != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FlockerVolumeSourceFluent that = (FlockerVolumeSourceFluent) o;
    if (!java.util.Objects.equals(datasetName, that.datasetName)) return false;
  
    if (!java.util.Objects.equals(datasetUUID, that.datasetUUID)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(datasetName,  datasetUUID,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (datasetName != null) { sb.append("datasetName:"); sb.append(datasetName + ","); }
    if (datasetUUID != null) { sb.append("datasetUUID:"); sb.append(datasetUUID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> kubernetes-model-core-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/FlockerVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FlockerVolumeSourceFluent<A extends FlockerVolumeSourceFluent<A>> extends BaseFluent<A>{
  public FlockerVolumeSourceFluent() {
  }
  
  public FlockerVolumeSourceFluent(FlockerVolumeSource instance) {
    this.copyInstance(instance);
  }
  private String datasetName;
  private String datasetUUID;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FlockerVolumeSource instance) {
    instance = (instance != null ? instance : new FlockerVolumeSource());
    if (instance != null) {
          this.withDatasetName(instance.getDatasetName());
          this.withDatasetUUID(instance.getDatasetUUID());
          this.withDatasetName(instance.getDatasetName());
          this.withDatasetUUID(instance.getDatasetUUID());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getDatasetName() {
    return this.datasetName;
  }
  
  public A withDatasetName(String datasetName) {
    this.datasetName = datasetName;
    return (A) this;
  }
  
  public boolean hasDatasetName() {
    return this.datasetName != null;
  }
  
  public String getDatasetUUID() {
    return this.datasetUUID;
  }
  
  public A withDatasetUUID(String datasetUUID) {
    this.datasetUUID = datasetUUID;
    return (A) this;
  }
  
  public boolean hasDatasetUUID() {
    return this.datasetUUID != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FlockerVolumeSourceFluent that = (FlockerVolumeSourceFluent) o;
    if (!java.util.Objects.equals(datasetName, that.datasetName)) return false;
    if (!java.util.Objects.equals(datasetUUID, that.datasetUUID)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(datasetName,  datasetUUID,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (datasetName != null) { sb.append("datasetName:"); sb.append(datasetName + ","); }
    if (datasetUUID != null) { sb.append("datasetUUID:"); sb.append(datasetUUID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
